
xhorizon
================================

xhorizon: Explicitly computed Penrose diagrams in general relativity.


 - Successful local source build!
 - Successful local doc build!
 - Successfully ran test file and both example scripts!
 - Successful PyPi Upload!
